Class: Aws::WAFRegional::Types::CreateRateBasedRuleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFRegional::Types::CreateRateBasedRuleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafregional/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#change_token ⇒ String
The
ChangeTokenthat you used to submit theCreateRateBasedRulerequest. -
#metric_name ⇒ String
A friendly name or description for the metrics for this
RateBasedRule. -
#name ⇒ String
A friendly name or description of the RateBasedRule.
-
#rate_key ⇒ String
The field that AWS WAF uses to determine if requests are likely arriving from a single source and thus subject to rate monitoring.
-
#rate_limit ⇒ Integer
The maximum number of requests, which have an identical value in the field that is specified by
RateKey, allowed in a five-minute period. - #tags ⇒ Array<Types::Tag>
Instance Attribute Details
#change_token ⇒ String
The ChangeToken that you used to submit the CreateRateBasedRule request. You can also use this value to query the status of the request. For more information, see GetChangeTokenStatus.
709 710 711 712 713 714 715 716 717 718 |
# File 'lib/aws-sdk-wafregional/types.rb', line 709 class CreateRateBasedRuleRequest < Struct.new( :name, :metric_name, :rate_key, :rate_limit, :change_token, :tags) SENSITIVE = [] include Aws::Structure end |
#metric_name ⇒ String
A friendly name or description for the metrics for this RateBasedRule. The name can contain only alphanumeric characters (A-Z, a-z, 0-9), with maximum length 128 and minimum length one. It can’t contain whitespace or metric names reserved for AWS WAF, including “All” and “Default_Action.” You can’t change the name of the metric after you create the RateBasedRule.
709 710 711 712 713 714 715 716 717 718 |
# File 'lib/aws-sdk-wafregional/types.rb', line 709 class CreateRateBasedRuleRequest < Struct.new( :name, :metric_name, :rate_key, :rate_limit, :change_token, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A friendly name or description of the RateBasedRule. You can’t change the name of a RateBasedRule after you create it.
709 710 711 712 713 714 715 716 717 718 |
# File 'lib/aws-sdk-wafregional/types.rb', line 709 class CreateRateBasedRuleRequest < Struct.new( :name, :metric_name, :rate_key, :rate_limit, :change_token, :tags) SENSITIVE = [] include Aws::Structure end |
#rate_key ⇒ String
The field that AWS WAF uses to determine if requests are likely arriving from a single source and thus subject to rate monitoring. The only valid value for RateKey is IP. IP indicates that requests that arrive from the same IP address are subject to the RateLimit that is specified in the RateBasedRule.
709 710 711 712 713 714 715 716 717 718 |
# File 'lib/aws-sdk-wafregional/types.rb', line 709 class CreateRateBasedRuleRequest < Struct.new( :name, :metric_name, :rate_key, :rate_limit, :change_token, :tags) SENSITIVE = [] include Aws::Structure end |
#rate_limit ⇒ Integer
The maximum number of requests, which have an identical value in the field that is specified by RateKey, allowed in a five-minute period. If the number of requests exceeds the RateLimit and the other predicates specified in the rule are also met, AWS WAF triggers the action that is specified for this rule.
709 710 711 712 713 714 715 716 717 718 |
# File 'lib/aws-sdk-wafregional/types.rb', line 709 class CreateRateBasedRuleRequest < Struct.new( :name, :metric_name, :rate_key, :rate_limit, :change_token, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
709 710 711 712 713 714 715 716 717 718 |
# File 'lib/aws-sdk-wafregional/types.rb', line 709 class CreateRateBasedRuleRequest < Struct.new( :name, :metric_name, :rate_key, :rate_limit, :change_token, :tags) SENSITIVE = [] include Aws::Structure end |