Class: Aws::WAFRegional::Types::ListSqlInjectionMatchSetsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFRegional::Types::ListSqlInjectionMatchSetsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafregional/types.rb
Overview
The response to a ListSqlInjectionMatchSets request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_marker ⇒ String
If you have more SqlInjectionMatchSet objects than the number that you specified for
Limitin the request, the response includes aNextMarkervalue. -
#sql_injection_match_sets ⇒ Array<Types::SqlInjectionMatchSetSummary>
An array of SqlInjectionMatchSetSummary objects.
Instance Attribute Details
#next_marker ⇒ String
If you have more SqlInjectionMatchSet objects than the number that
you specified for Limit in the request, the response includes a
NextMarker value. To list more SqlInjectionMatchSet objects,
submit another ListSqlInjectionMatchSets request, and specify the
NextMarker value from the response in the NextMarker value in
the next request.
3428 3429 3430 3431 3432 3433 |
# File 'lib/aws-sdk-wafregional/types.rb', line 3428 class ListSqlInjectionMatchSetsResponse < Struct.new( :next_marker, :sql_injection_match_sets) SENSITIVE = [] include Aws::Structure end |
#sql_injection_match_sets ⇒ Array<Types::SqlInjectionMatchSetSummary>
An array of SqlInjectionMatchSetSummary objects.
3428 3429 3430 3431 3432 3433 |
# File 'lib/aws-sdk-wafregional/types.rb', line 3428 class ListSqlInjectionMatchSetsResponse < Struct.new( :next_marker, :sql_injection_match_sets) SENSITIVE = [] include Aws::Structure end |