Class: Aws::WAFRegional::Types::ListSubscribedRuleGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFRegional::Types::ListSubscribedRuleGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafregional/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#limit ⇒ Integer
Specifies the number of subscribed rule groups that you want AWS WAF to return for this request.
-
#next_marker ⇒ String
If you specify a value for
Limitand you have moreByteMatchSetssubscribed rule groups than the value ofLimit, AWS WAF returns aNextMarkervalue in the response that allows you to list another group of subscribed rule groups.
Instance Attribute Details
#limit ⇒ Integer
Specifies the number of subscribed rule groups that you want AWS WAF
to return for this request. If you have more objects than the number
you specify for Limit, the response includes a NextMarker value
that you can use to get another batch of objects.
3454 3455 3456 3457 3458 3459 |
# File 'lib/aws-sdk-wafregional/types.rb', line 3454 class ListSubscribedRuleGroupsRequest < Struct.new( :next_marker, :limit) SENSITIVE = [] include Aws::Structure end |
#next_marker ⇒ String
If you specify a value for Limit and you have more
ByteMatchSetssubscribed rule groups than the value of Limit, AWS
WAF returns a NextMarker value in the response that allows you to
list another group of subscribed rule groups. For the second and
subsequent ListSubscribedRuleGroupsRequest requests, specify the
value of NextMarker from the previous response to get information
about another batch of subscribed rule groups.
3454 3455 3456 3457 3458 3459 |
# File 'lib/aws-sdk-wafregional/types.rb', line 3454 class ListSubscribedRuleGroupsRequest < Struct.new( :next_marker, :limit) SENSITIVE = [] include Aws::Structure end |