Class: Aws::WAFRegional::Types::RuleGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::WAFRegional::Types::RuleGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-wafregional/types.rb
Overview
For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.
A collection of predefined rules that you can add to a web ACL.
Rule groups are subject to the following limits:
-
Three rule groups per account. You can request an increase to this limit by contacting customer support.
-
One rule group per web ACL.
-
Ten rules per rule group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metric_name ⇒ String
A friendly name or description for the metrics for this
RuleGroup. -
#name ⇒ String
The friendly name or description for the
RuleGroup. -
#rule_group_id ⇒ String
A unique identifier for a
RuleGroup.
Instance Attribute Details
#metric_name ⇒ String
A friendly name or description for the metrics for this RuleGroup.
The name can contain only alphanumeric characters (A-Z, a-z, 0-9),
with maximum length 128 and minimum length one. It can't contain
whitespace or metric names reserved for AWS WAF, including "All"
and "Default_Action." You can't change the name of the metric
after you create the RuleGroup.
4382 4383 4384 4385 4386 4387 4388 |
# File 'lib/aws-sdk-wafregional/types.rb', line 4382 class RuleGroup < Struct.new( :rule_group_id, :name, :metric_name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The friendly name or description for the RuleGroup. You can't
change the name of a RuleGroup after you create it.
4382 4383 4384 4385 4386 4387 4388 |
# File 'lib/aws-sdk-wafregional/types.rb', line 4382 class RuleGroup < Struct.new( :rule_group_id, :name, :metric_name) SENSITIVE = [] include Aws::Structure end |
#rule_group_id ⇒ String
A unique identifier for a RuleGroup. You use RuleGroupId to get
more information about a RuleGroup (see GetRuleGroup), update a
RuleGroup (see UpdateRuleGroup), insert a RuleGroup into a
WebACL or delete a one from a WebACL (see UpdateWebACL), or
delete a RuleGroup from AWS WAF (see DeleteRuleGroup).
RuleGroupId is returned by CreateRuleGroup and by ListRuleGroups.
4382 4383 4384 4385 4386 4387 4388 |
# File 'lib/aws-sdk-wafregional/types.rb', line 4382 class RuleGroup < Struct.new( :rule_group_id, :name, :metric_name) SENSITIVE = [] include Aws::Structure end |