Class: Aws::WAFRegional::Types::UpdateByteMatchSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-wafregional/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#byte_match_set_idString

The ByteMatchSetId of the ByteMatchSet that you want to update. ByteMatchSetId is returned by CreateByteMatchSet and by ListByteMatchSets.



5389
5390
5391
5392
5393
5394
5395
# File 'lib/aws-sdk-wafregional/types.rb', line 5389

class UpdateByteMatchSetRequest < Struct.new(
  :byte_match_set_id,
  :change_token,
  :updates)
  SENSITIVE = []
  include Aws::Structure
end

#change_tokenString

The value returned by the most recent call to GetChangeToken.



5389
5390
5391
5392
5393
5394
5395
# File 'lib/aws-sdk-wafregional/types.rb', line 5389

class UpdateByteMatchSetRequest < Struct.new(
  :byte_match_set_id,
  :change_token,
  :updates)
  SENSITIVE = []
  include Aws::Structure
end

#updatesArray<Types::ByteMatchSetUpdate>

An array of ByteMatchSetUpdate objects that you want to insert into or delete from a ByteMatchSet. For more information, see the applicable data types:

  • ByteMatchSetUpdate: Contains Action and ByteMatchTuple

  • ByteMatchTuple: Contains FieldToMatch, PositionalConstraint, TargetString, and TextTransformation

  • FieldToMatch: Contains Data and Type



5389
5390
5391
5392
5393
5394
5395
# File 'lib/aws-sdk-wafregional/types.rb', line 5389

class UpdateByteMatchSetRequest < Struct.new(
  :byte_match_set_id,
  :change_token,
  :updates)
  SENSITIVE = []
  include Aws::Structure
end